#ifndef NT2_INCLUDE_FUNCTIONS_REDUCE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_REDUCE_HPP_INCLUDED

#include <nt2/polynom/include/functions/reduce.hpp>

#endif
